@@ -1200,12 +1200,7 @@ dLL.ODPdt <- function(theta, MU, G, workarea) {
     # ... and an intermediate value used in second derivative
     workarea$cmuminus1 <- workarea$value/workarea$mu-1
     # Return a vector of column sums
-    .Internal(colSums(
-                workarea$cmuminus1 * workarea$dmudt,
-                (dm <- dim(workarea$dmudt))[1L], 
-                dm[2L], 
-                FALSE
-                ))  
+    colSums(workarea$cmuminus1 * workarea$dmudt)  
     }
 
 d2LL.ODPdt2 <- function(theta, MU, G, workarea) {
@@ -1221,17 +1216,13 @@ d2LL.ODPdt2 <- function(theta, MU, G, workarea) {
     #   The second term is the outer product of (not the square of --
     #   we need a matrix not a vector) two first partial derivatives
     #   of the MU function times the quantity cit/mu^2.
-    y <- .Internal(colSums(
-                workarea$cmuminus1 * workarea$d2mudt2 -
+    y <- colSums(
+                 workarea$cmuminus1 * workarea$d2mudt2 -
                 (workarea$value/(workarea$mu^2)) *
                     t(vapply(1:workarea$nobs, function(i)
                         c(outer(workarea$dmudt[i, ], workarea$dmudt[i, ])),
                         vector("double", length(theta)^2)
-                        )),
-                (dm <- dim(workarea$d2mudt2))[1L], # 55
-                dm[2L],                            # 144
-                FALSE
-                ))  
+                        )))  
     dim(y) <- rep(length(theta), 2)
     y
     }
